AMapCluster<T> class

A group of items produced by buildAMapClusters.

Constructors

AMapCluster({required List<T> items, required LatLng center, required String cellKey, required bool isCluster})

Properties

cellKey String
final
center → LatLng
final
count int
no setter
first → T
no setter
hashCode int
The hash code for this object.
no setterinherited
isCluster bool
final
items List<T>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited