AMapClusterOptions class
Controls how markers are grouped into clusters in Dart space.
Constructors
Properties
- disableClusteringZoom → double
-
final
- enableClustering → bool
-
final
- gridSizePx → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxZoom → double?
-
final
- minClusterSize → int
-
final
- minZoom → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? enableClustering, double? gridSizePx, double? disableClusteringZoom, int? minClusterSize, double? minZoom, double? maxZoom}) → AMapClusterOptions -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldClusterAtZoom(
double zoom) → bool -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited